@@ -20,7 +20,8 @@
  * USA
  */
 
-#include <config.h>
+#include "config.h"
+
 #include <gdk/gdkx.h>
 #include <gdk/gdkkeysyms.h>
 #include <fcntl.h>
@@ -142,7 +143,7 @@ save_pixbuf_handle_error (ScreenshotApplication *self,
           gchar *folder_uri = g_path_get_basename (folder);
           gchar *folder_name = g_uri_unescape_string (folder_uri, NULL);
           gchar *file_name = screenshot_dialog_get_filename (dialog);
-          gchar *detail = g_strdup_printf (_("A file named \"%s\" already exists in \"%s\""),
+          gchar *detail = g_strdup_printf (_("A file named “%s” already exists in “%s”"),
                                            file_name, folder_name);
           gint response;
                                              
@@ -282,19 +283,6 @@ save_with_description (ScreenshotApplication *self,
                                    NULL);
 }
 
-static void
-save_with_profile (ScreenshotApplication *self,
-                   GFileOutputStream     *os,
-                   gchar                 *format)
-{
-  gdk_pixbuf_save_to_stream_async (self->priv->screenshot,
-                                   G_OUTPUT_STREAM (os),
-                                   format, NULL,
-                                   save_pixbuf_ready_cb, self,
-                                   "icc-profile", self->priv->icc_profile_base64,
-                                   NULL);
-}
-
 static void
 save_with_no_profile_or_description (ScreenshotApplication *self,
                                      GFileOutputStream     *os,
@@ -832,6 +820,7 @@ screenshot_application_startup (GApplication *app)
 
   screenshot_load_config ();
 
+  g_set_application_name (_("Screenshot"));
   gtk_window_set_default_icon_name (SCREENSHOOTER_ICON);
 
   g_action_map_add_action_entries (G_ACTION_MAP (self), action_entries,
