@@ -15,10 +15,11 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  */
 
-#include <config.h>
+#include "config.h"
+
 #include <gtk/gtk.h>
 
 #include "screenshot-area-selection.h"
