@@ -20,9 +20,7 @@
 
 /* Shadow code from anders */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "config.h"
 
 #include "screenshot-shadow.h"
 #include <math.h>
